#
# Copyright 3D Control Systems, Inc. All Rights Reserved 2017-2019. Built in San Francisco.
#
# This software is distributed under commercial non-GPL license for personal, educational,
# corporate or any other use. The software as a whole or any parts of that are prohibited
# for distribution and/or use without obtaining license from 3D Control Systems, Inc.
#
# If you do not have the license to use this software, please delete all software files
# immediately and contact sales to obtain the license: sales@3dprinteros.com.
# If you are unsure about the licensing please contact directly our sales: sales@3dprinteros.com.

import io
import sys
import time

from dual_cam import Camera


class RPiCamera(Camera):
    def start(self):
        try:
            import picamera
        except ImportError:
            self.logger.info("Can't import picamera module. Please install it with apt-get install python-picamera")
        try:
            self.capture = picamera.PiCamera()
            self.logger.info("Got connection to PiCamera")
        except Exception:
            self.logger.warning("Can't init PiCamera. Camera seems to be not connected or not enabled in RPi config.")
        else:
            self.main_loop()

    def get_camera_number_for_cloud(self):
        return 2

    def main_loop(self):
        self.resized.append(True)
        self.fails.append(0)
        time.sleep(self.min_loop_time)
        while not self.stop_flag:
            frame_start_time = time.time()
            if self.is_same_image_frame():
                img = self.SAME_IMAGE_FRAME
            else:
                stream = io.BytesIO()
                self.capture.capture(stream, format='jpeg')
                img = stream.getvalue()
                img = self.resize_small_image(img)
            self.send_frame(img)
            while time.time() < frame_start_time + 0.001 + self.min_loop_time:
                time.sleep(0.01)
        self.capture.close()
        self.http_client.close()
        sys.exit(0)

if __name__ == "__main__":
    RPiCamera()
